@@ -1,7 +1,7 @@
 package Code::Includable::Tree::NodeMethods;
 
-our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-04-02'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 # we must contain no other functions
 
@@ -32,6 +32,17 @@ sub descendants {
     @$res;
 }
 
+sub ancestors {
+    my $self = shift;
+    my @res;
+    my $p = $self->parent;
+    while ($p) {
+        push @res, $p;
+        $p = $p->parent;
+    }
+    @res;
+}
+
 sub walk {
     my ($self, $code) = @_;
     for (descendants($self)) {
@@ -199,7 +210,7 @@ Code::Includable::Tree::NodeMethods - Tree node routines
 
 =head1 VERSION
 
-This document describes version 0.08 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-29.
+This document describes version 0.09 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-04-02.
 
 =head1 DESCRIPTION
 
